==> certmanager-model-v1alpha3-6.6.1-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/CertificateKeystoresFluentImpl.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CertificateKeystoresFluentImpl<A extends CertificateKeystoresFluent<A>> extends BaseFluent<A> implements CertificateKeystoresFluent<A>{
  public CertificateKeystoresFluentImpl() {
  }
  public CertificateKeystoresFluentImpl(CertificateKeystores instance) {
    this.withJks(instance.getJks()); 
    this.withPkcs12(instance.getPkcs12()); 
  }
  private JKSKeystoreBuilder jks;
  private PKCS12KeystoreBuilder pkcs12;
  
  /**
   * This method has been deprecated, please use method buildJks instead.
   * @return The buildable object.
   */
  @Deprecated
  public JKSKeystore getJks() {
    return this.jks!=null ?this.jks.build():null;
  }
  public JKSKeystore buildJks() {
    return this.jks!=null ?this.jks.build():null;
  }
  public A withJks(JKSKeystore jks) {
    _visitables.get("jks").remove(this.jks);
    if (jks!=null){ this.jks= new JKSKeystoreBuilder(jks); _visitables.get("jks").add(this.jks);} else { this.jks = null; _visitables.get("jks").remove(this.jks); } return (A) this;
  }
  public Boolean hasJks() {
    return this.jks != null;
  }
  public CertificateKeystoresFluent.JksNested<A> withNewJks() {
    return new CertificateKeystoresFluentImpl.JksNestedImpl();
  }
  public CertificateKeystoresFluent.JksNested<A> withNewJksLike(JKSKeystore item) {
    return new CertificateKeystoresFluentImpl.JksNestedImpl(item);
  }
  public CertificateKeystoresFluent.JksNested<A> editJks() {
    return withNewJksLike(getJks());
  }
  public CertificateKeystoresFluent.JksNested<A> editOrNewJks() {
    return withNewJksLike(getJks() != null ? getJks(): new JKSKeystoreBuilder().build());
  }
  public CertificateKeystoresFluent.JksNested<A> editOrNewJksLike(JKSKeystore item) {
    return withNewJksLike(getJks() != null ? getJks(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildPkcs12 instead.
   * @return The buildable object.
   */
  @Deprecated
  public PKCS12Keystore getPkcs12() {
    return this.pkcs12!=null ?this.pkcs12.build():null;
  }
  public PKCS12Keystore buildPkcs12() {
    return this.pkcs12!=null ?this.pkcs12.build():null;
  }
  public A withPkcs12(PKCS12Keystore pkcs12) {
    _visitables.get("pkcs12").remove(this.pkcs12);
    if (pkcs12!=null){ this.pkcs12= new PKCS12KeystoreBuilder(pkcs12); _visitables.get("pkcs12").add(this.pkcs12);} else { this.pkcs12 = null; _visitables.get("pkcs12").remove(this.pkcs12); } return (A) this;
  }
  public Boolean hasPkcs12() {
    return this.pkcs12 != null;
  }
  public CertificateKeystoresFluent.Pkcs12Nested<A> withNewPkcs12() {
    return new CertificateKeystoresFluentImpl.Pkcs12NestedImpl();
  }
  public CertificateKeystoresFluent.Pkcs12Nested<A> withNewPkcs12Like(PKCS12Keystore item) {
    return new CertificateKeystoresFluentImpl.Pkcs12NestedImpl(item);
  }
  public CertificateKeystoresFluent.Pkcs12Nested<A> editPkcs12() {
    return withNewPkcs12Like(getPkcs12());
  }
  public CertificateKeystoresFluent.Pkcs12Nested<A> editOrNewPkcs12() {
    return withNewPkcs12Like(getPkcs12() != null ? getPkcs12(): new PKCS12KeystoreBuilder().build());
  }
  public CertificateKeystoresFluent.Pkcs12Nested<A> editOrNewPkcs12Like(PKCS12Keystore item) {
    return withNewPkcs12Like(getPkcs12() != null ? getPkcs12(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CertificateKeystoresFluentImpl that = (CertificateKeystoresFluentImpl) o;
    if (jks != null ? !jks.equals(that.jks) :that.jks != null) return false;
    if (pkcs12 != null ? !pkcs12.equals(that.pkcs12) :that.pkcs12 != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(jks,  pkcs12,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (jks != null) { sb.append("jks:"); sb.append(jks + ","); }
    if (pkcs12 != null) { sb.append("pkcs12:"); sb.append(pkcs12); }
    sb.append("}");
    return sb.toString();
  }
  class JksNestedImpl<N> extends JKSKeystoreFluentImpl<CertificateKeystoresFluent.JksNested<N>> implements CertificateKeystoresFluent.JksNested<N>,Nested<N>{
    JksNestedImpl(JKSKeystore item) {
      this.builder = new JKSKeystoreBuilder(this, item);
    }
    JksNestedImpl() {
      this.builder = new JKSKeystoreBuilder(this);
    }
    JKSKeystoreBuilder builder;
    public N and() {
      return (N) CertificateKeystoresFluentImpl.this.withJks(builder.build());
    }
    public N endJks() {
      return and();
    }
    
  }
  class Pkcs12NestedImpl<N> extends PKCS12KeystoreFluentImpl<CertificateKeystoresFluent.Pkcs12Nested<N>> implements CertificateKeystoresFluent.Pkcs12Nested<N>,Nested<N>{
    Pkcs12NestedImpl(PKCS12Keystore item) {
      this.builder = new PKCS12KeystoreBuilder(this, item);
    }
    Pkcs12NestedImpl() {
      this.builder = new PKCS12KeystoreBuilder(this);
    }
    PKCS12KeystoreBuilder builder;
    public N and() {
      return (N) CertificateKeystoresFluentImpl.this.withPkcs12(builder.build());
    }
    public N endPkcs12() {
      return and();
    }
    
  }
  
}

==> certmanager-model-v1alpha3-6.7.2-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/CertificateKeystoresFluentImpl.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CertificateKeystoresFluentImpl<A extends CertificateKeystoresFluent<A>> extends BaseFluent<A> implements CertificateKeystoresFluent<A>{
  public CertificateKeystoresFluentImpl() {
  }
  public CertificateKeystoresFluentImpl(CertificateKeystores instance) {
    if (instance != null) {
      this.withJks(instance.getJks());
      this.withPkcs12(instance.getPkcs12());
    }
  }
  private JKSKeystoreBuilder jks;
  private PKCS12KeystoreBuilder pkcs12;
  
  /**
   * This method has been deprecated, please use method buildJks instead.
   * @return The buildable object.
   */
  @Deprecated
  public JKSKeystore getJks() {
    return this.jks!=null ?this.jks.build():null;
  }
  public JKSKeystore buildJks() {
    return this.jks!=null ?this.jks.build():null;
  }
  public A withJks(JKSKeystore jks) {
    _visitables.get("jks").remove(this.jks);
    if (jks!=null){ this.jks= new JKSKeystoreBuilder(jks); _visitables.get("jks").add(this.jks);} else { this.jks = null; _visitables.get("jks").remove(this.jks); } return (A) this;
  }
  public Boolean hasJks() {
    return this.jks != null;
  }
  public CertificateKeystoresFluentImpl.JksNested<A> withNewJks() {
    return new CertificateKeystoresFluentImpl.JksNestedImpl();
  }
  public CertificateKeystoresFluentImpl.JksNested<A> withNewJksLike(JKSKeystore item) {
    return new CertificateKeystoresFluentImpl.JksNestedImpl(item);
  }
  public CertificateKeystoresFluentImpl.JksNested<A> editJks() {
    return withNewJksLike(getJks());
  }
  public CertificateKeystoresFluentImpl.JksNested<A> editOrNewJks() {
    return withNewJksLike(getJks() != null ? getJks(): new JKSKeystoreBuilder().build());
  }
  public CertificateKeystoresFluentImpl.JksNested<A> editOrNewJksLike(JKSKeystore item) {
    return withNewJksLike(getJks() != null ? getJks(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildPkcs12 instead.
   * @return The buildable object.
   */
  @Deprecated
  public PKCS12Keystore getPkcs12() {
    return this.pkcs12!=null ?this.pkcs12.build():null;
  }
  public PKCS12Keystore buildPkcs12() {
    return this.pkcs12!=null ?this.pkcs12.build():null;
  }
  public A withPkcs12(PKCS12Keystore pkcs12) {
    _visitables.get("pkcs12").remove(this.pkcs12);
    if (pkcs12!=null){ this.pkcs12= new PKCS12KeystoreBuilder(pkcs12); _visitables.get("pkcs12").add(this.pkcs12);} else { this.pkcs12 = null; _visitables.get("pkcs12").remove(this.pkcs12); } return (A) this;
  }
  public Boolean hasPkcs12() {
    return this.pkcs12 != null;
  }
  public CertificateKeystoresFluentImpl.Pkcs12Nested<A> withNewPkcs12() {
    return new CertificateKeystoresFluentImpl.Pkcs12NestedImpl();
  }
  public CertificateKeystoresFluentImpl.Pkcs12Nested<A> withNewPkcs12Like(PKCS12Keystore item) {
    return new CertificateKeystoresFluentImpl.Pkcs12NestedImpl(item);
  }
  public CertificateKeystoresFluentImpl.Pkcs12Nested<A> editPkcs12() {
    return withNewPkcs12Like(getPkcs12());
  }
  public CertificateKeystoresFluentImpl.Pkcs12Nested<A> editOrNewPkcs12() {
    return withNewPkcs12Like(getPkcs12() != null ? getPkcs12(): new PKCS12KeystoreBuilder().build());
  }
  public CertificateKeystoresFluentImpl.Pkcs12Nested<A> editOrNewPkcs12Like(PKCS12Keystore item) {
    return withNewPkcs12Like(getPkcs12() != null ? getPkcs12(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CertificateKeystoresFluentImpl that = (CertificateKeystoresFluentImpl) o;
    if (!java.util.Objects.equals(jks, that.jks)) return false;

    if (!java.util.Objects.equals(pkcs12, that.pkcs12)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(jks,  pkcs12,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (jks != null) { sb.append("jks:"); sb.append(jks + ","); }
    if (pkcs12 != null) { sb.append("pkcs12:"); sb.append(pkcs12); }
    sb.append("}");
    return sb.toString();
  }
  class JksNestedImpl<N> extends JKSKeystoreFluentImpl<CertificateKeystoresFluentImpl.JksNested<N>> implements CertificateKeystoresFluentImpl.JksNested<N>,Nested<N>{
    JksNestedImpl(JKSKeystore item) {
      this.builder = new JKSKeystoreBuilder(this, item);
    }
    JksNestedImpl() {
      this.builder = new JKSKeystoreBuilder(this);
    }
    JKSKeystoreBuilder builder;
    public N and() {
      return (N) CertificateKeystoresFluentImpl.this.withJks(builder.build());
    }
    public N endJks() {
      return and();
    }
    
  }
  class Pkcs12NestedImpl<N> extends PKCS12KeystoreFluentImpl<CertificateKeystoresFluentImpl.Pkcs12Nested<N>> implements CertificateKeystoresFluentImpl.Pkcs12Nested<N>,Nested<N>{
    Pkcs12NestedImpl(PKCS12Keystore item) {
      this.builder = new PKCS12KeystoreBuilder(this, item);
    }
    Pkcs12NestedImpl() {
      this.builder = new PKCS12KeystoreBuilder(this);
    }
    PKCS12KeystoreBuilder builder;
    public N and() {
      return (N) CertificateKeystoresFluentImpl.this.withPkcs12(builder.build());
    }
    public N endPkcs12() {
      return and();
    }
    
  }
  
}
